api.users.v1.group — Argus-Toolbelt 1.0 documentation

# Source code for api.users.v1.group

    """Autogenerated API"""
    import requests
    from argus_cli.plugin import register_command

    @register_command(extending=('users','v1','group'))
    def list_groups(subjectID: list = None, offset: int = None, limit: int = 25,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Get group information (PUBLIC)

        :param list subjectID: IDs of groups
        :param int offset: Offset results
        :param int limit: Limit results
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :returns: {"offset": 258, "limit": 985, "responseCode": 200, "count": 706, "data": [{"id": 717, "customerID": 880, "description": "Case artist economic skin.", "name": "Daryl White"}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Hair property tonight economic yourself ball.", "messageTemplate": "Official run notice into significant.", "field": "Perhaps thank east.", "parameter": {}, "timestamp": 597471013}], "currentPage": 323, "size": 882}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/group".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if limit:
            body.update({"limit": limit})

        if subjectID:
            body.update({"subjectID": subjectID})

        if offset:
            body.update({"offset": offset})

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('users','v1','group'))
    def find_groups(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, domain: list = None, type: str = None, subjectID: list = None, excludeSubjectID: list = None, parentID: list = None, ancestorID: list = None, get_aclAncestorID: list = None, get_aclCustomerID: list = None, excludeAncestorID: list = None, userName: list = None, email: list = None, mobile: list = None, searchString: str = None, languageID: list = None, requiredFunctionID: list = None, requiredFunctionCustomerID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', requireAllFunctions: bool = 'False',json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Search group profiles (PUBLIC)

        :param int limit: Set this value to set max number of results. By default, no restriction on result set size.
        :param int offset: Set this value to skip the first (offset) objects. By default, return result from first object.
        :param int includeFlags: Only include objects which have includeFlags set.
        :param int excludeFlags: Exclude objects which have excludeFlags set.
        :param list subCriteria:
        :param list customerID: Restrict search to data belonging to specified customers.
        :param list domain:
        :param str type:
        :param list subjectID:
        :param list excludeSubjectID:
        :param list parentID:
        :param list ancestorID:
        :param list get_aclAncestorID:
        :param list get_aclCustomerID:
        :param list excludeAncestorID:
        :param list userName:
        :param list email:
        :param list mobile:
        :param str searchString:
        :param list languageID:
        :param list requiredFunctionID:
        :param int requiredFunctionCustomerID:
        :param bool includeDeleted: Set to true to include deleted objects. By default, exclude deleted objects.
        :param bool exclude: Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded.
        :param bool required: Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
        :param bool requireAllFunctions:
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :returns: {"offset": 12, "limit": 785, "responseCode": 200, "count": 504, "data": [{"id": 67, "userName": "ritterethan", "name": "Robert Kelly", "createdTimestamp": 850341818, "createdByUser": {"id": 106, "customerID": 729, "userName": "csalazar", "name": "Amanda Lee"}, "lastUpdatedTimestamp": 198995418, "lastUpdatedByUser": {"id": 35, "customerID": 979, "userName": "bryanpotter", "name": "Laura Morales"}, "properties": {"additionalProperties": "Thank material popular campaign must together admit."}, "groupName": "Entire friend sure include picture close.", "description": "Democrat interview religious yes thousand.", "ascendantIDs": [660], "flags": ["AUTH_LDAP"]}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Water market level real scientist.", "messageTemplate": "Anyone within need education you.", "field": "Might wind return site every.", "parameter": {}, "timestamp": 671908437}], "currentPage": 639, "size": 956}
        """
        from requests import post
        from argus_api.exceptions import http

        url = "https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/group/search".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if limit:
            body.update({"limit": limit})

        if offset:
            body.update({"offset": offset})

        if includeDeleted:
            body.update({"includeDeleted": includeDeleted})

        if includeFlags:
            body.update({"includeFlags": includeFlags})

        if excludeFlags:
            body.update({"excludeFlags": excludeFlags})

        if subCriteria:
            body.update({"subCriteria": subCriteria})

        if exclude:
            body.update({"exclude": exclude})

        if required:
            body.update({"required": required})

        if customerID:
            body.update({"customerID": customerID})

        if domain:
            body.update({"domain": domain})

        if type:
            body.update({"type": type})

        if subjectID:
            body.update({"subjectID": subjectID})

        if excludeSubjectID:
            body.update({"excludeSubjectID": excludeSubjectID})

        if parentID:
            body.update({"parentID": parentID})

        if ancestorID:
            body.update({"ancestorID": ancestorID})

        if get_aclAncestorID:
            body.update({"get_aclAncestorID": get_aclAncestorID})

        if get_aclCustomerID:
            body.update({"get_aclCustomerID": get_aclCustomerID})

        if excludeAncestorID:
            body.update({"excludeAncestorID": excludeAncestorID})

        if userName:
            body.update({"userName": userName})

        if email:
            body.update({"email": email})

        if mobile:
            body.update({"mobile": mobile})

        if searchString:
            body.update({"searchString": searchString})

        if languageID:
            body.update({"languageID": languageID})

        if requiredFunctionID:
            body.update({"requiredFunctionID": requiredFunctionID})

        if requiredFunctionCustomerID:
            body.update({"requiredFunctionCustomerID": requiredFunctionCustomerID})

        if requireAllFunctions:
            body.update({"requireAllFunctions": requireAllFunctions})

        response = post(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('users','v1','group'))
    def get_gropu_by_id(groupId: int,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Get group profile by ID (PUBLIC)

        :param int groupId: ID of group
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises ObjectNotFoundException: on 404
        :returns: {"offset": 313, "limit": 49, "responseCode": 200, "count": 618, "metaData": {"additionalProperties": {}}, "messages": [{"message": "According something seat.", "messageTemplate": "Firm none have data call.", "field": "Probably serious American establish suddenly.", "parameter": {}, "timestamp": 300097531}], "currentPage": 937, "size": 230}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/group/{groupId}".format(groupId=groupId)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('users','v1','group'))
    def get_group_by_name(groupName: str,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Get group profile by name (PUBLIC)

        :param str groupName: Group shortname
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises ObjectNotFoundException: on 404
        :returns: {"offset": 60, "limit": 147, "responseCode": 200, "count": 135, "metaData": {"additionalProperties": {}}, "messages": [{"message": "International pull report high support alone nation become.", "messageTemplate": "Computer whose interesting notice future.", "field": "What tough player two body.", "parameter": {}, "timestamp": 559418215}], "currentPage": 80, "size": 102}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://osl-argus-trunk-web1.mnemonic.no/web/api/users/v1/group/{groupName}".format(groupName=groupName)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response